@@ -65,7 +65,7 @@ static QVariant GetButtonName(
 		case Qt::LeftButton:
 		{
 			if (clickCount > 1 && clickCount <= 4) {
-				return QString("%1-Left").arg(clickCount);
+				return QStringLiteral("%1-Left").arg(clickCount);
 			}
 			return QStringLiteral("Left");
 		}
@@ -79,6 +79,12 @@ static QVariant GetButtonName(
 		case Qt::NoButton:
 			return QLatin1String{""};
 
+		case Qt::XButton1:
+			return QStringLiteral("X1");
+
+		case Qt::XButton2:
+			return QStringLiteral("X2");
+
 		default:
 			return {}; // Invalid
 	}
