@@ -1,8 +1,10 @@
 #include "mainwindow.h"
 
+#include <QApplication>
 #include <QCloseEvent>
 #include <QEventLoop>
 #include <QLayout>
+#include <QScreen>
 #include <QSettings>
 #include <QStyleFactory>
 #include <QToolBar>
@@ -14,6 +16,23 @@ static QString DefaultWindowTitle() noexcept
 	return "Neovim";
 }
 
+static void SetDefaultWindowSize(QWidget& widget) noexcept
+{
+	const QPoint local_position{ widget.width() / 2, 0 };
+	const QPoint global_position{ widget.mapToGlobal(local_position) };
+	const QScreen* screen{ qApp->screenAt(global_position) };
+	if (!screen) {
+		return;
+	}
+	const QRect geometry{ screen->availableGeometry() };
+	if (screen->orientation() == Qt::LandscapeOrientation) {
+		widget.resize(geometry.width() / 2, geometry.height());
+	}
+	else {
+		widget.resize(geometry.width(), geometry.height() / 2);
+	}
+}
+
 MainWindow::MainWindow(NeovimConnector* c, QWidget* parent) noexcept
 	: QMainWindow{ parent }
 	, m_tabline{ *c, this }
@@ -132,7 +151,7 @@ void MainWindow::neovimExited(int status)
 		m_errorWidget->showReconnect(m_nvim->canReconnect());
 		m_stack.setCurrentIndex(0);
 	} else if (status != 0) {
-		m_errorWidget->setText(QString("Neovim exited with status code (%1)").arg(status));
+		m_errorWidget->setText(QStringLiteral("Neovim exited with status code (%1)").arg(status));
 		m_errorWidget->showReconnect(m_nvim->canReconnect());
 		m_stack.setCurrentIndex(0);
 	} else {
@@ -155,7 +174,8 @@ void MainWindow::neovimError(NeovimConnector::NeovimError err)
 }
 void MainWindow::neovimIsUnsupported()
 {
-	m_errorWidget->setText(QString("Cannot connect to this Neovim, required API version 1, found [%1-%2]")
+	m_errorWidget->setText(
+		QStringLiteral("Cannot connect to this Neovim, required API version 1, found [%1-%2]")
 			.arg(m_nvim->apiCompatibility())
 			.arg(m_nvim->apiLevel()));
 	m_errorWidget->showReconnect(m_nvim->canReconnect());
@@ -311,7 +331,12 @@ Shell* MainWindow::shell()
 
 void MainWindow::saveWindowGeometry()
 {
-	QSettings settings{ "window-geometry" };
+	QSettings settings("nvim-qt", "window-geometry");
+	const bool restore_window_geometry{ settings.value("restore_window_geometry", true).toBool() };
+	if (!restore_window_geometry) {
+		return;
+	}
+	settings.setValue("restore_window_geometry", restore_window_geometry);
 	settings.setValue("window_geometry", saveGeometry());
 	settings.setValue("window_state", saveState());
 }
@@ -324,9 +349,21 @@ void MainWindow::restoreWindowGeometry()
 	qRegisterMetaTypeStreamOperators<QList<int>>("QList<int>");
 #endif
 
-	QSettings settings{ "window-geometry" };
-	restoreGeometry(settings.value("window_geometry").toByteArray());
-	restoreState(settings.value("window_state").toByteArray());
+	QSettings settings("nvim-qt", "window-geometry");
+	if (!settings.value("restore_window_geometry", true).toBool()) {
+		return;
+	}
+	const QVariant geometry{ settings.value("window_geometry") };
+	if (geometry.isValid()) {
+		restoreGeometry(geometry.toByteArray());
+	}
+	else {
+		SetDefaultWindowSize(*this);
+	}
+	const QVariant state{ settings.value("window_state") };
+	if (state.isValid()) {
+		restoreState(state.toByteArray());
+	}
 }
 
 void MainWindow::setGuiAdaptiveColorEnabled(bool isEnabled)
